@@ -5,26 +5,30 @@ use strict;
 use warnings;
 use Padre::Task::FunctionList ();
 
-our $VERSION = '0.86';
+our $VERSION = '0.88';
 our @ISA     = 'Padre::Task::FunctionList';
 
-
-
-
 # TODO: the regex containing func|method should either reuse what
 # we have in PPIx::EditorTools::Outline or copy the list from there
 # for now let's leave it as it is and focus on improving the Outline
 # code and then we'll see if we reuse or copy paste.
+
 ######################################################################
 # Padre::Task::FunctionList Methods
+
 my $n = "\\cM?\\cJ";
 our $sub_search_re = qr/
 		(?:
-		${n}__(?:DATA|END)__\b.*
-		|
-		$n$n=\w+.*?$n\s*?$n=cut\b(?=.*?(?:$n){1,2})
-		|
-		(?:^|$n)\s*(?:sub|func|method)\s+(\w+(?:::\w+)*)
+			${n}__(?:DATA|END)__\b.*
+			|
+			$n$n=\w+.*?$n\s*?$n=cut\b(?=.*?(?:$n){1,2})
+			|
+			(?:^|$n)\s*
+			(?:
+				(?:sub|func|method)\s+(\w+(?:::\w+)*)
+				|
+				\* (\w+(?:::\w+)*) \s*=\s* (?: sub\b | \\\& )
+			)
 		)
 	/sx;
 
