@@ -7,13 +7,12 @@ use Padre::Constant          ();
 use Padre::Task::Syntax      ();
 use Parse::ErrorString::Perl ();
 
-our $VERSION = '0.86';
+our $VERSION = '0.88';
 our @ISA     = 'Padre::Task::Syntax';
 
 sub new {
 	my $class = shift;
-
-	my %args = @_;
+	my %args  = @_;
 
 	if ( defined $ENV{PADRE_IS_TEST} ) {
 
@@ -23,7 +22,7 @@ sub new {
 		$args{perl} = Padre::Perl::cperl();
 	} else {
 
-		#Otherwise run with user-preferred interpreter
+		# Otherwise run with user-preferred interpreter
 		$args{perl} = $args{document}->get_interpreter;
 	}
 
@@ -50,7 +49,7 @@ sub syntax {
 		require File::Temp;
 		my $file = File::Temp->new( UNLINK => 1 );
 		$filename = $file->filename;
-		binmode( $file, ':utf8' );
+		binmode( $file, ':encoding(UTF-8)' );
 
 		# If this is a module, we will need to overwrite %INC to avoid the module
 		# loading another module, which loads the system installed equivalent
