@@ -5,6 +5,7 @@ package Padre::Wx;
 use 5.008;
 use strict;
 use warnings;
+use constant ();
 
 # Threading must be loaded before Wx loads
 use threads;
@@ -17,11 +18,10 @@ use Wx         (':everything');
 use Wx         ('wxTheClipboard');
 use Wx::Event  (':everything');
 use Wx::DND    ();
-use Wx::STC    ();
 use Wx::AUI    ();
 use Wx::Locale ();
 
-our $VERSION    = '0.86';
+our $VERSION    = '0.88';
 our $COMPATIBLE = '0.43';
 
 # Hard version lock on a new-enough Wx.pm
@@ -31,6 +31,41 @@ BEGIN {
 	}
 }
 
+sub import {
+	my $class = shift;
+	unless ( $_[0] and $_[0] eq ':api2' ) {
+		return;
+	}
+
+	# Scan for all of the Wx::wxFOO AUTOLOAD functions and
+	# check that we can create Wx::FOO constants.
+	my %constants = ();
+	foreach my $function ( sort map { /^wx([A-Z].+)$/ ? $1 : () } keys %Wx:: ) {
+		next if $function eq 'VERSION';
+		next if $function =~ /^Log[A-Z]/;
+		if ( exists $Wx::{$function} ) {
+			warn "Clash with function Wx::$function";
+			next;
+		}
+		if ( exists $Wx::{"${function}::"} ) {
+			warn "Pseudoclash with namespace Wx::${function}::";
+			next;
+		}
+		my $error = 0;
+		my $value = Wx::constant( "wx$function", 0, $error );
+		next if $error;
+		$constants{$function} = $value;
+	}
+
+	# Convert to proper constants
+	SCOPE: {
+		package Wx; ## no critic
+		constant::->import(\%constants);
+	}
+
+	return 1;
+}
+
 
 
 
