@@ -8,7 +8,7 @@ use Padre::Config   ();
 use Padre::Constant ();
 use Padre::Wx       ();
 
-our $VERSION = '0.86';
+our $VERSION = '0.88';
 
 # Generate faster accessors
 use Class::XSAccessor {
@@ -30,37 +30,6 @@ use Class::XSAccessor {
 
 
 
-#####################################################################
-# Functions
-
-# This sub calls all the other files which actually create the actions
-sub create {
-	my $main = shift;
-
-	# This is made for usage by the developers to create a complete
-	# list of all actions used in Padre. It outputs some warnings
-	# while dumping, but they're ignored for now as it should never
-	# run within a productional copy.
-	if ( $ENV{PADRE_EXPORT_ACTIONS} ) {
-		require Data::Dumper;
-		require File::Spec;
-		$Data::Dumper::Purity = $Data::Dumper::Purity = 1;
-		open(
-			my $action_export_fh,
-			'>',
-			File::Spec->catfile(
-				Padre::Constant::CONFIG_DIR,
-				'actions.dump',
-			),
-		);
-		print $action_export_fh Data::Dumper::Dumper( $_[0]->ide->actions );
-		close $action_export_fh;
-	}
-
-}
-
-
-
 #####################################################################
 # Constructor
 
@@ -171,7 +140,8 @@ sub label_menu {
 	my $shortcut = $self->shortcut;
 
 	if ( $shortcut
-		and ( ( $shortcut eq 'F12' ) or ( $self->id == -1 or Padre::Constant::WIN32() ) ) )
+		and ( ( $shortcut eq 'F12' ) 
+			or ( $self->id == -1 or Padre::Constant::WIN32() or Padre::Constant::MAC()) ) )
 	{
 		$label .= "\t" . $shortcut;
 	}
