@@ -8,7 +8,7 @@ use Padre::Config         ();
 use Padre::Wx             ();
 use Padre::Wx::Role::Main ();
 
-our $VERSION = '0.86';
+our $VERSION = '0.88';
 our @ISA     = qw{
 	Padre::Wx::Role::Main
 	Wx::Dialog
@@ -740,7 +740,10 @@ sub _update_list {
 	foreach my $name (@preference_names) {
 
 		# Ignore setting if it does not match the filter
-		next if $name !~ /$filter/i;
+		# An empty pattern would use the last successful
+		# regex which means arbitrary filter matching (MARKD)
+		# next if $name !~ /$filter/i
+		next if ( length($filter) && $name !~ /$filter/i );
 
 		# Add the setting to the list control
 		my $pref       = $preferences->{$name};
