@@ -6,6 +6,8 @@ use warnings;
 use YAML::Tiny                ();
 use Time::HiRes               ();
 use Padre::Constant           ();
+use Padre::Config             ();
+use Padre::Feature            ();
 use Padre::Util               ();
 use Padre::DB                 ();
 use Padre::Wx                 ();
@@ -13,17 +15,17 @@ use Padre::Wx::FileDropTarget ();
 use Padre::Wx::Role::Main     ();
 use Padre::Logger;
 
-our $VERSION    = '0.86';
+our $VERSION    = '0.88';
 our $COMPATIBLE = '0.81';
 
-# NOTE: Wx::ScintillaTextCtrl (Wx::Scintilla) or Wx::StyledTextCtrl (Wx::STC) is added later
-# before object construction
-our @ISA = qw {	Padre::Wx::Role::Main };
+# Allow the use of two different versions of Scintilla
+our @ISA = Padre::Config::wx_scintilla_ready()
+	? qw{ Padre::Wx::Role::Main Wx::ScintillaTextCtrl }
+	: qw{ Padre::Wx::Role::Main Wx::StyledTextCtrl    };
 
 # Convenience colour constants
+# NOTE: DO NOT USE "orange" string since it is actually red on win32
 use constant {
-
-	# NOTE: DO NOT USE "orange" string since it is actually red on win32
 	ORANGE => Wx::Colour->new( 255, 165, 0 ),
 	RED    => Wx::Colour->new("red"),
 	GREEN  => Wx::Colour->new("green"),
@@ -36,6 +38,7 @@ use constant {
 #
 # Please note that WIN32 is the API. DO NOT change it to that :)
 #
+# Initialize variables after loading either Wx::Scintilla or Wx::STC
 my %WXEOL = (
 	WIN  => Wx::wxSTC_EOL_CRLF,
 	MAC  => Wx::wxSTC_EOL_CR,
@@ -43,30 +46,26 @@ my %WXEOL = (
 );
 
 # mapping for mime-type to the style name in the share/styles/default.yml file
+# TODO this should be defined in MimeTypes.pm
 our %MIME_STYLE = (
-	'application/x-perl' => 'perl',
-	'application/x-psgi' => 'perl',
-	'text/x-perlxs'      => 'xs',   # should be in the plugin...
-	'text/x-patch'       => 'diff',
-	'text/x-makefile'    => 'make',
-	'text/x-yaml'        => 'yaml',
-	'text/css'           => 'css',
-	'application/x-php'  => 'perl', # temporary solution
+	'application/x-perl'     => 'perl',
+	'application/x-psgi'     => 'perl',
+	'text/x-perlxs'          => 'xs',   # should be in the plugin...
+	'text/x-patch'           => 'diff',
+	'text/x-makefile'        => 'make',
+	'text/x-yaml'            => 'yaml',
+	'text/css'               => 'css',
+	'application/x-php'      => 'perl', # temporary solution
+	'text/x-c'               => 'c',
+	'text/x-c++src'          => 'c',
+	'text/x-csharp'          => 'c',
+	'application/javascript' => 'c',
+	'text/x-java-source'     => 'c',
 );
 
-# Karl
-# these are the allowed braces for brace highlighting and brace matching
-# this has to be subset of  ( ) [ ] { } < > since we use the scintilla
-# Brace* methods
-# always altern opening and starting braces in the constant
-my $BRACES               = '{}[]()';
-my $STC_INVALID_POSITION = Wx::wxSTC_INVALID_POSITION;
-
 my $data;
 my $data_name;
 my $data_private;
-my $width;
-my $Clipboard_Old = '';
 
 sub new {
 	my $class  = shift;
@@ -79,18 +78,6 @@ sub new {
 		$main = $main->GetParent;
 	}
 
-	# Figure out what to use as this editor instance super class
-	# Wx::ScintillaTextCtrl which needs to be installed (i.e. cpanm Wx::Scintilla),
-	# or Wx::StyledTextCtrl which comes by default with Wx and is very *old*
-	my $editor_super_class = 'Wx::StyledTextCtrl';
-	if ( $main->config->feature_wx_scintilla ) {
-		eval "use Wx::Scintilla";
-		$editor_super_class = 'Wx::ScintillaTextCtrl' unless $@;
-	}
-
-	# Push the appropriate editor super class to inheritance list :)
-	push @ISA, $editor_super_class;
-
 	# Create the underlying Wx object
 	my $lock = $main->lock( 'UPDATE', 'refresh_windowlist' );
 	my $self = $class->SUPER::new($parent);
@@ -134,10 +121,6 @@ sub new {
 		BLUE,
 	);
 
-	# Set word chars to match Perl variables
-	### This should probably move somewhere Perl-specific
-	$self->SetWordChars( join '', '$@%&_:[]{}', 0 .. 9, 'A' .. 'Z', 'a' .. 'z' );
-
 	# No more unsafe CTRL-L for you :)
 	# CTRL-L or line cut should only work when there is no empty line
 	# This prevents the accidental destruction of the clipboard
@@ -244,50 +227,58 @@ sub error {
 # Most of this should be read from some external files
 # but for now we use this if statement
 sub padre_setup {
-	my $self = shift;
+	my $self     = shift;
+	my $document = $self->{Document};
+	my $mimetype = $document ? $document->mimetype : '';
+	my $filename = $document ? $document->filename : '';
 
-	TRACE("before setting the lexer") if DEBUG;
-	if ( $self->{Document} ) {
-		$self->SetLexer( $self->{Document}->lexer );
+	# Configure lexing for the editor based on the document type
+	if ( $document ) {
+		$self->SetLexer( $document->lexer );
+		$self->SetWordChars( $document->stc_word_chars );
+
+		# Set all the lexer keywords lists that the document provides
+		my @lexer_keywords = @{ $document->lexer_keywords };
+		for my $i ( 0 .. $#lexer_keywords ) {
+			$self->SetKeyWords($i, join(' ', @{$lexer_keywords[$i]}));
+		}
+	} else {
+		$self->SetWordChars('');
 	}
 
-	# the next line will change the ESC key to cut the current selection
-	# See: http://www.yellowbrain.com/stc/keymap.html
-	#$self->CmdKeyAssign(Wx::wxSTC_KEY_ESCAPE, 0, Wx::wxSTC_CMD_CUT);
-
 	# This is supposed to be Wx::wxSTC_CP_UTF8
 	# and Wx::wxUNICODE or wxUSE_UNICODE should be on
 	$self->SetCodePage(65001);
 
-	my $mimetype = $self->{Document} ? $self->{Document}->mimetype : '';
+	# Setup the style for the specific mimetype
 	$mimetype ||= 'text/plain';
-
 	if ( $MIME_STYLE{$mimetype} ) {
 		$self->padre_setup_style( $MIME_STYLE{$mimetype} );
-
-	} elsif ( $mimetype eq 'text/plain' ) {
-		$self->padre_setup_plain;
-		my $filename = $self->{Document} ? $self->{Document}->filename : '';
-		$filename ||= '';
-		if ( $filename and $filename =~ /\.([^.]+)$/ ) {
-			my $ext = lc $1;
-
-			# re-setup if file extension is .conf
-			$self->padre_setup_style('conf') if $ext eq 'conf';
-		}
-
-	} elsif ($mimetype) {
-
-		# setup some default coloring
-		# for the time being it is the same as for Perl
-		$self->padre_setup_style('padre');
-	} else {
-
-		# if mimetype is not known, then no coloring for now
-		# but mimimal configuration should apply here too
-		$self->padre_setup_plain;
+		return;
 	}
 
+	# Setup some default colouring.
+	# For the time being it is the same as for Perl.
+	unless ( $mimetype ne 'text/plain' ) {
+		$self->padre_setup_style('padre');
+		return;
+	}
+
+	# For plain text try to guess based on the filename
+	if ( $filename and $filename =~ /\.([^.]+)$/ ) {
+		my $ext = lc $1;
+
+		# Resetup if file extension is .conf
+		if ( $ext eq 'conf' ) {
+			$self->padre_setup_style('conf');
+			return;
+		}
+	}
+
+	# if mimetype is not known, then no coloring for now
+	# but mimimal configuration should apply here too
+	$self->padre_setup_plain;
+
 	return;
 }
 
@@ -381,7 +372,7 @@ sub padre_setup_plain {
 sub padre_setup_style {
 	my $self   = shift;
 	my $name   = shift;
-	my $config = $self->main->ide->config;
+	my $config = $self->main->config;
 
 	$self->padre_setup_plain;
 	for ( 0 .. Wx::wxSTC_STYLE_DEFAULT ) {
@@ -389,10 +380,11 @@ sub padre_setup_style {
 	}
 	$self->setup_style_from_config($name);
 
-	# if mimetype is known, then it might
-	# be Perl with in-line POD
-	if ( $config->editor_folding and $config->editor_fold_pod ) {
-		$self->fold_pod;
+	# if mimetype is known, then it might be Perl with in-line POD
+	if ( Padre::Feature::FOLDING and $config->editor_folding ) {
+		if ( $config->editor_fold_pod ) {
+			$self->fold_pod;
+		}
 	}
 
 	return;
@@ -492,13 +484,13 @@ sub remove_color {
 
 =head2 get_brace_info
 
-Look at a given position in the editor if there is a brace (according to the 
+Look at a given position in the editor if there is a brace (according to the
 setting editor_braces) before or after, and return the information about the context
 It always look first at the character after the position.
 
 	Params:
 		pos - the cursor position in the editor [defaults to cursor position) : int
-		
+
 	Return:
 		undef if no brace, otherwise [brace, actual_pos, is_after, is_opening]
 		where:
@@ -506,10 +498,10 @@ It always look first at the character after the position.
 			actual_pos - the actual position where the brace has been found
 			is_after - true iff the brace is after the cursor : boolean
 			is_opening - true iff only the brace is an opening one
-			
+
 	Examples:
 
-		|{} => should find the { : [0,{,1,1] 
+		|{} => should find the { : [0,{,1,1]
 		{|} => should find the } : [1,},1,0]
 		{| } => should find the { : [0,{,0,1]
 
@@ -540,7 +532,7 @@ Tell if a character is a brace, and if it is an opening or a closing one
 
 	Params:
 		char - a character : string
-		
+
 	Return:
 		int : 0 if this is not a brace, an odd value if it is an opening brace and an even
 		one for a closing brace
@@ -553,7 +545,7 @@ sub get_brace_type {
 	my ( $self, $char ) = @_;
 	unless (%_cached_braces) {
 		my $i = 1; # start from one so that all values are true
-		$_cached_braces{$_} = $i++ foreach ( split //, $BRACES );
+		$_cached_braces{$_} = $i++ foreach ( split //, '{}[]()' );
 	}
 	my $v = $_cached_braces{$char} or return 0;
 	return $v;
@@ -587,7 +579,7 @@ sub highlight_braces {
 	my $expression_highlighting = $self->config->editor_brace_expression_highlighting;
 
 	# remove current highlighting if any
-	$self->BraceHighlight( $STC_INVALID_POSITION, $STC_INVALID_POSITION );
+	$self->BraceHighlight( Wx::wxSTC_INVALID_POSITION, Wx::wxSTC_INVALID_POSITION );
 	if ($previous_expr_hiliting_style) {
 		$self->apply_style($previous_expr_hiliting_style);
 		$previous_expr_hiliting_style = undef;
@@ -599,9 +591,7 @@ sub highlight_braces {
 
 	my $actual_pos2 = $self->BraceMatch($actual_pos1);
 
-	#	return if abs( $pos1 - $pos2 ) < 2;
-
-	return if $actual_pos2 == $STC_INVALID_POSITION; #Wx::wxSTC_INVALID_POSITION  #????
+	return if $actual_pos2 == Wx::wxSTC_INVALID_POSITION; #Wx::wxSTC_INVALID_POSITION  #????
 
 	$self->BraceHighlight( $actual_pos1, $actual_pos2 );
 
@@ -621,12 +611,12 @@ sub highlight_braces {
 
 =head2 find_matching_brace
 
-Find the position of to the matching brace if any. If the cursor is inside the braces the destination 
+Find the position of to the matching brace if any. If the cursor is inside the braces the destination
 will be inside too, same it is outside.
 
 	Params:
 		pos - the cursor position in the editor [defaults to cursor position) : int
-		
+
 	Return:
 		matching_pos - the matching position, or undef if none
 
@@ -639,7 +629,7 @@ sub find_matching_brace {
 	my ( $actual_pos1, $brace, $is_after, $is_opening ) = @$info1;
 
 	my $actual_pos2 = $self->BraceMatch($actual_pos1);
-	return if $actual_pos2 == $STC_INVALID_POSITION;
+	return if $actual_pos2 == Wx::wxSTC_INVALID_POSITION;
 	$actual_pos2++ if $is_after; # ensure is stays inside if origin is inside, same four outside
 	return $actual_pos2;
 }
@@ -647,12 +637,12 @@ sub find_matching_brace {
 
 =head2 goto_matching_brace
 
-Move the cursor to the matching brace if any. If the cursor is inside the braces the destination 
+Move the cursor to the matching brace if any. If the cursor is inside the braces the destination
 will be inside too, same it is outside.
 
 	Params:
 		pos - the cursor position in the editor [defaults to cursor position) : int
-		
+
 
 =cut
 
@@ -664,12 +654,12 @@ sub goto_matching_brace {
 
 =head2 select_to_matching_brace
 
-Select to the matching opening or closing brace. If the cursor is inside the braces the destination 
+Select to the matching opening or closing brace. If the cursor is inside the braces the destination
 will be inside too, same it is outside.
 
 	Params:
 		pos - the cursor position in the editor [defaults to cursor position) : int
-		
+
 
 
 =cut
@@ -688,14 +678,12 @@ sub select_to_matching_brace {
 # actually I added some improvement allowing a 50% growth in the file
 # and requireing a min of 2 width
 sub show_line_numbers {
-	my ( $self, $on ) = @_;
+	my $self = shift;
+	my $on   = shift;
 
-	# premature optimization, caching the with that was on the 3rd place at load time
-	# as timed my Deve::NYTProf
-	$width ||= $self->TextWidth( Wx::wxSTC_STYLE_LINENUMBER, "m" ); # width of a single character
 	if ($on) {
 		my $n = 1 + List::Util::max( 2, length( $self->GetLineCount * 2 ) );
-		my $width = $n * $width;
+		my $width = $n * $self->TextWidth( Wx::wxSTC_STYLE_LINENUMBER, "m" );
 		$self->SetMarginWidth( 0, $width );
 		$self->SetMarginType( 0, Wx::wxSTC_MARGIN_NUMBER );
 	} else {
@@ -706,20 +694,9 @@ sub show_line_numbers {
 	return;
 }
 
-# Just a placeholder
-sub show_symbols {
-	my ( $self, $on ) = @_;
-
-	#	$self->SetMarginWidth(1, 0);
-
-	# $self->SetMarginWidth(1, 16);   #margin 1 for symbols, 16 px wide
-	# $self->SetMarginType(1, Wx::wxSTC_MARGIN_SYMBOL);
-
-	return;
-}
-
 sub show_folding {
-	my ( $self, $on ) = @_;
+	my $self = shift;
+	my $on   = shift;
 
 	if ($on) {
 
@@ -729,7 +706,7 @@ sub show_folding {
 		$self->SetMarginSensitive( 2, 1 );                  # this one needs to be mouse-aware
 		$self->SetMarginWidth( 2, 16 );                     # set margin 2 16 px wide
 
-		# define folding markers
+		# Define folding markers
 		my $w = Wx::Colour->new("white");
 		my $b = Wx::Colour->new("black");
 		$self->MarkerDefine( Wx::wxSTC_MARKNUM_FOLDEREND,     Wx::wxSTC_MARK_BOXPLUSCONNECTED,  $w, $b );
@@ -778,14 +755,17 @@ sub show_folding {
 
 sub set_preferences {
 	my $self   = shift;
-	my $config = $self->main->ide->config;
+	my $config = $self->config;
 
+	$self->SetCaretLineVisible( $config->editor_currentline );
 	$self->show_line_numbers( $config->editor_linenumbers );
-	$self->show_folding( $config->editor_folding );
 	$self->SetIndentationGuides( $config->editor_indentationguides );
 	$self->SetViewEOL( $config->editor_eol );
 	$self->SetViewWhiteSpace( $config->editor_whitespace );
-	$self->SetCaretLineVisible( $config->editor_currentline );
+
+	if ( Padre::Feature::FOLDING ) {
+		$self->show_folding( $config->editor_folding );
+	}
 
 	$self->padre_setup;
 
@@ -859,7 +839,7 @@ sub _auto_indent {
 
 	my $indent_style = $self->{Document}->get_indentation_style;
 
-	my $content = $self->_get_line_by_number($prev_line);
+	my $content = $self->GetLine($prev_line);
 	my $indent = ( $content =~ /^(\s+)/ ? $1 : '' );
 
 	if ( $config->editor_autoindent eq 'deep' and $content =~ /\{\s*$/ ) {
@@ -899,13 +879,13 @@ sub _auto_deindent {
 
 	my $indent_style = $self->{Document}->get_indentation_style;
 
-	my $content = $self->_get_line_by_number($line);
+	my $content = $self->GetLine($line);
 	my $indent = ( $content =~ /^(\s+)/ ? $1 : '' );
 
 	# This is for } on a new line:
 	if ( $config->editor_autoindent eq 'deep' and $content =~ /^\s*\}\s*$/ ) {
 		my $prev_line    = $line - 1;
-		my $prev_content = ( $prev_line < 0 ? '' : $self->_get_line_by_number($prev_line) );
+		my $prev_content = ( $prev_line < 0 ? '' : $self->GetLine($prev_line) );
 		my $prev_indent  = ( $prev_content =~ /^(\s+)/ ? $1 : '' );
 
 		# de-indent only in these cases:
@@ -953,74 +933,63 @@ sub _auto_deindent {
 	return;
 }
 
-# given a line number, returns the contents
-sub _get_line_by_number {
-	my $self    = shift;
-	my $line_no = shift;
+BEGIN {
+	*fold_this = sub {
+		my $self        = shift;
+		my $currentLine = $self->GetCurrentLine;
 
-	my $start = $self->PositionFromLine($line_no);
-	my $end   = $self->GetLineEndPosition($line_no);
-	return $self->GetTextRange( $start, $end );
-}
-
-sub fold_this {
-	my ($self) = @_;
-
-	my $currentLine = $self->GetCurrentLine;
-
-	if ( !$self->GetFoldExpanded($currentLine) ) {
-		$self->ToggleFold($currentLine);
-		return;
-	}
-
-	while ( $currentLine >= 0 ) {
-		if ( ( my $parentLine = $self->GetFoldParent($currentLine) ) > 0 ) {
-			$self->ToggleFold($parentLine);
+		unless ( $self->GetFoldExpanded($currentLine) ) {
+			$self->ToggleFold($currentLine);
 			return;
-		} else {
-			$currentLine--;
 		}
-	}
 
-	return;
-}
-
-sub fold_all {
-	my ($self) = @_;
-
-	my $lineCount   = $self->GetLineCount;
-	my $currentLine = $lineCount;
-
-	while ( $currentLine >= 0 ) {
-		if ( ( my $parentLine = $self->GetFoldParent($currentLine) ) > 0 ) {
-			if ( $self->GetFoldExpanded($parentLine) ) {
+		while ( $currentLine >= 0 ) {
+			if ( ( my $parentLine = $self->GetFoldParent($currentLine) ) > 0 ) {
 				$self->ToggleFold($parentLine);
-				$currentLine = $parentLine;
+				return;
 			} else {
 				$currentLine--;
 			}
-		} else {
-			$currentLine--;
 		}
-	}
 
-	return;
-}
+		return;
+	} if Padre::Feature::FOLDING;
 
-sub unfold_all {
-	my ($self) = @_;
+	*fold_all = sub {
+		my $self        = shift;
+		my $lineCount   = $self->GetLineCount;
+		my $currentLine = $lineCount;
 
-	my $lineCount   = $self->GetLineCount;
-	my $currentLine = 0;
-
-	while ( $currentLine <= $lineCount ) {
-		if ( !$self->GetFoldExpanded($currentLine) ) {
-			$self->ToggleFold($currentLine);
+		while ( $currentLine >= 0 ) {
+			if ( ( my $parentLine = $self->GetFoldParent($currentLine) ) > 0 ) {
+				if ( $self->GetFoldExpanded($parentLine) ) {
+					$self->ToggleFold($parentLine);
+					$currentLine = $parentLine;
+				} else {
+					$currentLine--;
+				}
+			} else {
+				$currentLine--;
+			}
 		}
-		$currentLine++;
-	}
 
-	return;
+		return;
+	} if Padre::Feature::FOLDING;
+
+	*unfold_all = sub {
+		my $self        = shift;
+		my $lineCount   = $self->GetLineCount;
+		my $currentLine = 0;
+
+		while ( $currentLine <= $lineCount ) {
+			if ( !$self->GetFoldExpanded($currentLine) ) {
+				$self->ToggleFold($currentLine);
+			}
+			$currentLine++;
+		}
+
+		return;
+	} if Padre::Feature::FOLDING;
 }
 
 # When the focus is received by the editor
@@ -1254,7 +1223,7 @@ sub on_mousewheel {
 		return;
 	}
 
-	if ( $self->config->feature_fontsize ) {
+	if ( Padre::Feature::FONTSIZE ) {
 
 		# The default handler zooms in the wrong direction
 		$self->SetZoom( $self->GetZoom + int( $event->GetWheelRotation / $event->GetWheelDelta ) );
@@ -1267,44 +1236,36 @@ sub on_mousewheel {
 	return;
 }
 
-sub text_select_all {
-	my ( $main, $event ) = @_;
-
-	my $id = $main->notebook->GetSelection;
-	return if $id == -1;
-	$main->notebook->GetPage($id)->SelectAll;
-	return;
-}
-
 sub text_selection_mark_start {
-	my ($self) = @_;
-
-	# find positions
+	my $self = shift;
 	$self->{selection_mark_start} = $self->GetCurrentPos;
 
-	# change selection if start and end are defined
-	$self->SetSelection(
-		$self->{selection_mark_start},
-		$self->{selection_mark_end}
-	) if defined $self->{selection_mark_end};
+	# Change selection if start and end are defined
+	if ( defined $self->{selection_mark_end} ) {
+		$self->SetSelection(
+			$self->{selection_mark_start},
+			$self->{selection_mark_end}
+		);
+	}
 }
 
 sub text_selection_mark_end {
-	my ($self) = @_;
-
+	my $self = shift;
 	$self->{selection_mark_end} = $self->GetCurrentPos;
 
-	# change selection if start and end are defined
-	$self->SetSelection(
-		$self->{selection_mark_start},
-		$self->{selection_mark_end}
-	) if defined $self->{selection_mark_start};
+	# Change selection if start and end are defined
+	if ( defined $self->{selection_mark_start} ) {
+		$self->SetSelection(
+			$self->{selection_mark_start},
+			$self->{selection_mark_end}
+		);
+	}
 }
 
-sub text_selection_clear_marks {
-	my $editor = $_[0]->current->editor;
-	undef $editor->{selection_mark_start};
-	undef $editor->{selection_mark_end};
+sub text_selection_clear {
+	my $editor = shift;
+	$editor->{selection_mark_start} = undef;
+	$editor->{selection_mark_end}   = undef;
 }
 
 #
@@ -1482,9 +1443,9 @@ sub get_text_from_clipboard {
 sub comment_toggle_lines {
 	my ( $self, $begin, $end, $str ) = @_;
 
-	my $comment_start = ref $str eq 'ARRAY' ? $str->[0] : $str;
+	my $comment = ref $str eq 'ARRAY' ? $str->[0] : $str;
 
-	if ( _get_line_by_number( $self, $begin ) =~ /^\s*\Q$comment_start\E/ ) {
+	if ( $self->GetLine($begin) =~ /^\s*\Q$comment\E/ ) {
 		uncomment_lines(@_);
 	} else {
 		comment_lines(@_);
@@ -1511,19 +1472,16 @@ sub comment_lines {
 		$self->InsertText( $pos, $str->[1] );
 	} else {
 		foreach my $line ( $begin .. $end ) {
-			my $text = _get_line_by_number( $self, $line );
-
-			# next if (length($text) == 0);  # should i do this?
-
+			my $text = $self->GetLine($line);
 			if ( $text =~ /^(\s*)/ ) {
 				my $pos = $self->PositionFromLine($line);
 				$pos += length($1);
 				$self->InsertText( $pos, $str . ' ' );
 			}
 		}
-
 	}
 	$self->EndUndoAction;
+
 	return;
 }
 
@@ -1554,7 +1512,7 @@ sub uncomment_lines {
 		}
 	} else {
 		foreach my $line ( $begin .. $end ) {
-			my $text = _get_line_by_number( $self, $line );
+			my $text = $self->GetLine($line);
 
 			# the first line starting with '#!' can't be uncommented!
 			next if ( $line == 0 && $text =~ /^#!/ );
@@ -1573,13 +1531,12 @@ sub uncomment_lines {
 }
 
 sub fold_pod {
-	my ($self) = @_;
-
+	my $self        = shift;
 	my $currentLine = 0;
 	my $lastLine    = $self->GetLineCount;
 
 	while ( $currentLine <= $lastLine ) {
-		if ( $self->_get_line_by_number($currentLine) =~ /^=(pod|head)/ ) {
+		if ( $self->GetLine($currentLine) =~ /^=(pod|head)/ ) {
 			if ( $self->GetFoldExpanded($currentLine) ) {
 				$self->ToggleFold($currentLine);
 				my $foldLevel = $self->GetFoldLevel($currentLine);
@@ -1596,13 +1553,14 @@ sub fold_pod {
 
 sub configure_editor {
 	my $self     = shift;
-	my $document = shift;
-
-	$self->SetEOLMode( $WXEOL{ $document->newline_type } );
+	my $document = shift or return;
+	my $eol      = $WXEOL{ $document->newline_type };
+	$self->SetEOLMode($eol) if defined $eol;
 
 	if ( defined $document->{original_content} ) {
 		$self->SetText( $document->{original_content} );
 	}
+
 	$self->EmptyUndoBuffer;
 
 	return;
@@ -1611,15 +1569,14 @@ sub configure_editor {
 sub goto_line_centerize {
 	my $self = shift;
 	my $line = shift;
-
 	$self->goto_pos_centerize( $self->GetLineIndentPosition($line) );
 }
 
 # borrowed from Kephra
 sub goto_pos_centerize {
-	my ( $self, $pos ) = @_;
-
-	my $max = $self->GetLength;
+	my $self = shift;
+	my $pos  = shift;
+	my $max  = $self->GetLength;
 	$pos = 0 unless $pos or $pos < 0;
 	$pos = $max if $pos > $max;
 
@@ -1627,7 +1584,7 @@ sub goto_pos_centerize {
 	$self->SearchAnchor;
 
 	my $line = $self->GetCurrentLine;
-	$self->ScrollToLine( $line - ( $self->LinesOnScreen / 2 ) );
+	$self->ScrollToLine( $line - $self->LinesOnScreen / 2 );
 	$self->EnsureVisible($line);
 	$self->EnsureCaretVisible;
 	$self->SetSelection( $pos, $pos );
@@ -1635,36 +1592,25 @@ sub goto_pos_centerize {
 }
 
 sub insert_text {
-	my ( $self, $text ) = @_;
-
-	my $data = Wx::TextDataObject->new;
-	$data->SetText($text);
-	my $length = $data->GetTextLength;
-
+	my $self = shift;
+	my $text = shift;
+	my $size = Wx::TextDataObject->new($text)->GetTextLength;
+	my $pos  = $self->GetCurrentPos;
 	$self->ReplaceSelection('');
-	my $pos = $self->GetCurrentPos;
 	$self->InsertText( $pos, $text );
-	$self->GotoPos( $pos + $length - 1 );
-
-	return;
+	$self->GotoPos( $pos + $size + 1 );
+	return 1;
 }
 
 sub insert_from_file {
-	my ( $self, $file ) = @_;
-
-	my $text;
-	if ( open( my $fh, '<', $file ) ) {
-		binmode($fh);
-		local $/ = undef;
-		$text = <$fh>;
-		close $fh;
-	} else {
-		return;
-	}
-
+	my $self = shift;
+	my $file = shift;
+	open( my $fh, '<', $file ) or return;
+	binmode($fh);
+	local $/ = undef;
+	my $text = <$fh>;
+	close $fh;
 	$self->insert_text($text);
-
-	return $file;
 }
 
 sub vertically_align {
@@ -1748,37 +1694,39 @@ sub needs_manual_colorize {
 ######################################################################
 # Cursor Memory
 
-#
-# $doc->store_cursor_position()
-#
-# store document's current cursor position in padre's db.
-# no params, no return value.
-#
-sub store_cursor_position {
-	my $self     = shift;
-	my $document = $self->{Document} or return;
-	my $file     = $document->{file} or return;
-	Padre::DB::LastPositionInFile->set_last_pos(
-		$file->filename,
-		$self->GetCurrentPos,
-	);
-}
+BEGIN {
+	#
+	# $doc->store_cursor_position()
+	#
+	# store document's current cursor position in padre's db.
+	# no params, no return value.
+	#
+	*store_cursor_position = sub {
+		my $self     = shift;
+		my $document = $self->{Document} or return;
+		my $file     = $document->{file} or return;
+		Padre::DB::LastPositionInFile->set_last_pos(
+			$file->filename,
+			$self->GetCurrentPos,
+		);
+	} if Padre::Feature::CURSORMEMORY;
 
-#
-# $doc->restore_cursor_position()
-#
-# restore document's cursor position from padre's db.
-# no params, no return value.
-#
-sub restore_cursor_position {
-	my $self     = shift;
-	my $document = $self->{Document} or return;
-	my $file     = $document->{file} or return;
-	my $filename = $file->filename;
-	my $position = Padre::DB::LastPositionInFile->get_last_pos($filename);
-	return unless defined $position;
-	$self->SetCurrentPos($position);
-	$self->SetSelection( $position, $position );
+	#
+	# $doc->restore_cursor_position()
+	#
+	# restore document's cursor position from padre's db.
+	# no params, no return value.
+	#
+	*restore_cursor_position = sub {
+		my $self     = shift;
+		my $document = $self->{Document} or return;
+		my $file     = $document->{file} or return;
+		my $filename = $file->filename;
+		my $position = Padre::DB::LastPositionInFile->get_last_pos($filename);
+		return unless defined $position;
+		$self->SetCurrentPos($position);
+		$self->SetSelection( $position, $position );
+	} if Padre::Feature::CURSORMEMORY;
 }
 
 1;
