@@ -14,7 +14,7 @@ use Padre::Wx::Menu ();
 use Padre::Locale   ();
 use Padre::Current  ();
 
-our $VERSION = '0.86';
+our $VERSION = '0.88';
 our @ISA     = 'Padre::Wx::Menu';
 
 
@@ -39,29 +39,28 @@ sub new {
 
 	# Perl-Specific Searches
 	$self->{beginner_check} = $self->add_menu_action(
-		$self,
 		'perl.beginner_check',
 	);
 
+	$self->{perl_deparse} = $self->add_menu_action(
+		'perl.deparse',
+	);
+
 	$self->AppendSeparator;
 
 	$self->{find_brace} = $self->add_menu_action(
-		$self,
 		'perl.find_brace',
 	);
 
 	$self->{find_variable} = $self->add_menu_action(
-		$self,
 		'perl.find_variable',
 	);
 
 	$self->{find_method} = $self->add_menu_action(
-		$self,
 		'perl.find_method',
 	);
 
 	$self->{create_tagsfile} = $self->add_menu_action(
-		$self,
 		'perl.create_tagsfile',
 	);
 
@@ -69,12 +68,10 @@ sub new {
 	$self->AppendSeparator;
 
 	$self->add_menu_action(
-		$self,
 		'perl.vertically_align_selected',
 	);
 
 	$self->add_menu_action(
-		$self,
 		'perl.newline_keep_column',
 	);
 
