@@ -7,144 +7,135 @@ use strict;
 use warnings;
 use Padre::Wx       ();
 use Padre::Wx::Menu ();
+use Padre::Feature  ();
 
-our $VERSION = '0.86';
+our $VERSION = '0.88';
 our @ISA     = 'Padre::Wx::Menu';
 
 sub new {
 	my $class  = shift;
 	my $main   = shift;
-	my $editor = shift;
+	my $editor = shift or return;
 	my $event  = shift;
 
-	return if not $editor;
-
 	# Create the empty menu as normal
 	my $self = $class->SUPER::new(@_);
 
 	# Add additional properties
 	$self->{main} = $main;
 
-	my $selection_exists = length( $editor->GetSelectedText ) > 0 ? 1 : 0;
+	my $selection = length( $editor->GetSelectedText ) > 0 ? 1 : 0;
 
 	# Undo/Redo
 	$self->{undo} = $self->add_menu_action(
-		$self,
 		'edit.undo',
 	);
-	if ( not $editor->CanUndo ) {
+	unless ( $editor->CanUndo ) {
 		$self->{undo}->Enable(0);
 	}
 
 	$self->{redo} = $self->add_menu_action(
-		$self,
 		'edit.redo',
 	);
-	if ( not $editor->CanRedo ) {
+	unless ( $editor->CanRedo ) {
 		$self->{redo}->Enable(0);
 	}
 
 	$self->AppendSeparator;
 
-	if ($selection_exists) {
+	if ($selection) {
 		$self->{open_selection} = $self->add_menu_action(
-			$self,
 			'file.open_selection',
 		);
 	}
 
 	$self->{open_in_file_browser} = $self->add_menu_action(
-		$self,
 		'file.open_in_file_browser',
 	);
 
 	$self->{find_in_files} = $self->add_menu_action(
-		$self,
 		'search.find_in_files',
 	);
 
 	$self->AppendSeparator;
 
-	$self->{copy} = $self->add_menu_action(
-		$self,
-		'edit.copy',
-	);
 	$self->{cut} = $self->add_menu_action(
-		$self,
 		'edit.cut',
 	);
 
-	if ( not $selection_exists ) {
+	$self->{copy} = $self->add_menu_action(
+		'edit.copy',
+	);
+
+	unless ($selection) {
 		$self->{copy}->Enable(0);
 		$self->{cut}->Enable(0);
 	}
 
-
 	$self->{paste} = $self->add_menu_action(
-		$self,
 		'edit.paste',
 	);
-	my $text = $editor->get_text_from_clipboard();
-	if ( not defined($text) or not length($text) or not $editor->CanPaste ) {
+	my $text = $editor->get_text_from_clipboard;
+	unless ( defined $text and length $text and $editor->CanPaste ) {
 		$self->{paste}->Enable(0);
 	}
 
 	$self->{select_all} = $self->add_menu_action(
-		$self,
 		'edit.select_all',
 	);
 
 	$self->AppendSeparator;
 
 	$self->{comment_toggle} = $self->add_menu_action(
-		$self,
 		'edit.comment_toggle',
 	);
 
 	$self->{comment} = $self->add_menu_action(
-		$self,
 		'edit.comment',
 	);
 
 	$self->{uncomment} = $self->add_menu_action(
-		$self,
 		'edit.uncomment',
 	);
 
+	my $config = $main->config;
+	if (
+		Padre::Feature::FOLDING
+		and
+		$event->isa('Wx::MouseEvent')
+		and
+		$config->editor_folding
+	) {
+		my $position = $event->GetPosition;
+		my $line     = $editor->LineFromPosition( $editor->PositionFromPoint($position) );
+		my $point    = $editor->PointFromPosition( $editor->PositionFromLine($line) );
 
-	if (    $event->isa('Wx::MouseEvent')
-		and $editor->main->ide->config->editor_folding )
-	{
-		my $mousePos         = $event->GetPosition;
-		my $line             = $editor->LineFromPosition( $editor->PositionFromPoint($mousePos) );
-		my $firstPointInLine = $editor->PointFromPosition( $editor->PositionFromLine($line) );
-
-		if (   $mousePos->x < $firstPointInLine->x
-			&& $mousePos->x > ( $firstPointInLine->x - 18 ) )
-		{
+		if ( $position->x < $point->x and $position->x > ( $point->x - 18 ) ) {
 			$self->AppendSeparator;
 
 			$self->{fold_all} = $self->add_menu_action(
-				$self,
 				'view.fold_all',
 			);
+
 			$self->{unfold_all} = $self->add_menu_action(
-				$self,
 				'view.unfold_all',
 			);
 
-			$self->AppendSeparator;
 		}
 	}
 
-	my $doc = $editor->{Document};
-	if ($doc) {
-		if ( $doc->can('event_on_right_down') ) {
-			$doc->event_on_right_down( $editor, $self, $event );
+	my $document = $editor->{Document};
+	if ( $document ) {
+		$self->AppendSeparator;
+
+		if ( $document->can('event_on_right_down') ) {
+			$document->event_on_right_down( $editor, $self, $event );
 		}
 
 		# Let the plugins have a go
-		$editor->main->ide->plugin_manager->on_context_menu( $doc, $editor, $self, $event );
+		$editor->main->ide->plugin_manager->on_context_menu(
+			$document, $editor, $self, $event,
+		);
 	}
 
 	return $self;
